@@ -1,7 +1,8 @@
-/*
- * $Id: renamedialog.h,v 1.1 2003/03/24 15:36:52 gibreel Exp $
+/* -*- c++ -*-
  *
- * Copyright (C) 2003 Petter E. Stokke <gibreel@gibreel.net>
+ * renamedialog.h
+ *
+ * Copyright (C) 2003 Petter E. Stokke <gibreel@kmldonkey.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,25 +18,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Log: renamedialog.h,v $
- * Revision 1.1  2003/03/24 15:36:52  gibreel
- * More work; still not complete, but getting there.
- *
  */
 
 #ifndef __kmldonkey_renamedialog_h__
 #define __kmldonkey_renamedialog_h__
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <kdialogbase.h>
-#include <klineedit.h>
-#include <kcombobox.h>
 
 #include <donkeyprotocol.h>
 
+class KLineEdit;
+class KComboBox;
+
 class RenameDialog : public KDialogBase
 {
     Q_OBJECT
@@ -48,7 +42,7 @@ protected slots:
     virtual void slotOk();
 
 signals:
-    void renameFile(int fileno, QString& name);
+    void renameFile(int fileno, const QString& name);
 
 private:
     DonkeyProtocol* donkey;
